/*
 * 20170721-16-9999.c
 *
 *	関数 sin の区間 [-π/4,π/6]] の定積分
 *
 *	コンパイル :
 *		cc -I ~/c/include -c 20170721-16-9999.c
 *		cc -o 20170721-16-9999.exe 20170721-16-9999.o
 *	実行 :
 *		./20170721-16-9999.exe
 *
 */

#include <stdio.h>
#include <math.h>		/* 数学的関数 F を利用するので.. */

#include "s_input.h"
#include "s_print.h"

/*
 * リーマン積分を利用する
 */

#define FRACTIONAL 1000 /* 区間の等分数 */

/*
 * f(x)=sin (x)
 */

double f(double x) {

	   /*
		* 引数 x に対して、x の 正弦 値 sin (x) を値として返す関数
		*/

	   return sin (x);
}

/*
 reman_sum ( int i, int n, double min, double max )
	S_i 〜 S_{n^1} の和を計算する
*/

double reman_sum ( int i, int n, double min, double max ) {

	if ( i < n )	{	/* まだ計算が必要 */
		/* 注目している短冊の面積と、残りの部分の面積の和を計算する */
		return
			reman_sum ( i + 1, n, min, max )
				+
			f(min+i*(max-min)/n)*(max-min)/n;
	} else {			/* もう、全て計算した */
		return 0.0;		/* 残る結果は 0 になる */
	}
}

/*
 * リーマン積分
 *
 *   関数の積分値が、小さな幅の短冊の面積の和で近似できる事を利用
 *
 *   solove_reaman ( double min, double max )
 *
 */

double solve_reman ( double min, double max ) {
	/*
       min から max までを積分
       基本は reman_sum に任せる
	*/

    return reman_sum ( 0, FRACTIONAL, min, max );
}

/*
 *	main 関数
 */

int main ( void ) {

	s_print_string ( "関数 f(x)=sin (x) を区間 [-π/4,π/6] で数値定積分する。\n" );

	s_print_string ( "リーマンの定義に従って計算した答えは : " );
	s_print_double ( solve_reman ( -M_PI/4.0, M_PI/6.0 ) );
	s_print_string ( " になりました。\n" );

	return 0;
}

